@@ -1,10 +1,17 @@
+####################################
+#		pyquicksql imports
+####################################
+
 from pyquicksql.utils import sql_enums, sql_enums, logger_enums, logger_errors
-
 from pyquicksql.mysql import mysql_set, mysql_lookup, mysql_modify, mysql_remove
-
 from pyquicksql.sqlite import sqlite_set,sqlite_lookup, sqlite_modify, sqlite_remove
 
+####################################
+#	    main pyquicksql class
+####################################
+
 class Connect:
+	
 	def __init__(self, server, database):
 		'''
 			(Server, Database) -> None
@@ -15,6 +22,7 @@ class Connect:
 		self.db_type = server.getName()
 		self.db_ip = server.getIP()
 		self.db_port = server.getPort()
+		
 	def getAccount(self):
 		'''
 			(None) -> (tuple)
@@ -28,6 +36,7 @@ class Connect:
 		'''
 		account = server.getAccount()
 		return (account[0], account[1]) #(username, password)
+		
 	def lookup(self, unknown_column, known_colum, known_element):
 		'''
 			(Connect, string, string, string) -> (string)
@@ -39,8 +48,7 @@ class Connect:
 		'''
 		if ( self.db_type == sql_enums.Name.MYSQL ):
 			return mysql_lookup.retreive(self.server, self.database, unknown_column, known_colum, known_element)
-		elif ( self.db_type == sql_enums.Name.SQLITE ):
-			return sqlite_lookup.retreive(self.server, self.database, unknown_column, known_colum, known_element)
+			
 	def push(self, columns, elements):
 		'''
 			(Connect, list of strings, list of strings) -> (boolean)
@@ -52,8 +60,7 @@ class Connect:
 		'''
 		if ( self.db_type == sql_enums.Name.MYSQL ):
 			return mysql_set.commit(self.server, self.database, columns, elements)
-		elif ( self.db_type == sql_enums.Name.SQLITE ):
-			return sqlite_set.commit(self.server, self.database, columns, elements)
+			
 	def swap(self, column, element, identifiers, identifier_elements):
 		'''
 			(Connect, ) -> (boolean)
@@ -64,8 +71,7 @@ class Connect:
 		'''
 		if ( self.db_type == sql_enums.Name.MYSQL ):
 			return mysql_modify.commit(self.server, self.database, column, element, identifiers, identifier_elements)
-		elif ( self.db_type == sql_enums.Name.SQLITE ):
-			return sqlite_modify.commit(self.server, self.database, column, element, identifiers, identifier_elements)
+			
 	def remove(self, column, element):
 		'''
 			(Connect, ) -> (string)
@@ -75,8 +81,7 @@ class Connect:
 		'''
 		if ( self.db_type == sql_enums.Name.MYSQL ):
 			return mysql_remove.commit(self.server, self.database, column, element)
-		elif ( self.db_type == sql_enums.Name.SQLITE ):
-			return sqlite_remove.commit(self.server, self.database, column, element)
+			
 	def __eq__(self, other):
 		'''
 			(Connect) -> (boolean)
@@ -89,6 +94,7 @@ class Connect:
 		#check if the sockets connect to the same port on the server
 		if this.db_port != other.db_port:
 			return false;
+	
 	def __repr__(self):
 		'''
 			(Connect) -> (string)
@@ -97,6 +103,7 @@ class Connect:
 		'''
 		account = server.getAccount()
 		return f'Connect({self.db_ip}, {self.db_port}, {account[0]}, {account[1]})'
+	
 	def __str__(self):
 		'''
 			(Connect) -> (string)
